==> juce-docs-6.1.2-2-aarch64.pkg.tar.xz: usr/share/doc/juce/html/menudata.js <==
/*
 @licstart  The following is the entire license notice for the JavaScript code in this file.

 The MIT License (MIT)

 Copyright (C) 1997-2020 by Dimitri van Heesch

 Permission is hereby granted, free of charge, to any person obtaining a copy of this software
 and associated documentation files (the "Software"), to deal in the Software without restriction,
 including without limitation the rights to use, copy, modify, merge, publish, distribute,
 sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in all copies or
 substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING
 BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

 @licend  The above is the entire license notice for the JavaScript code in this file
*/
var menudata={children:[
{text:"Main Page",url:"index.html"},
{text:"Related Pages",url:"pages.html"},
{text:"Modules",url:"modules.html"},
{text:"Classes",url:"annotated.html",children:[
{text:"Class List",url:"annotated.html"},
{text:"Class Index",url:"classes.html"},
{text:"Class Hierarchy",url:"hierarchy.html"},
{text:"Class Members",url:"functions.html",children:[
{text:"All",url:"functions.html",children:[
{text:"_",url:"functions.html#index__5F"},
{text:"a",url:"functions_a.html#index_a"},
{text:"b",url:"functions_b.html#index_b"},
{text:"c",url:"functions_c.html#index_c"},
{text:"d",url:"functions_d.html#index_d"},
{text:"e",url:"functions_e.html#index_e"},
{text:"f",url:"functions_f.html#index_f"},
{text:"g",url:"functions_g.html#index_g"},
{text:"h",url:"functions_h.html#index_h"},
{text:"i",url:"functions_i.html#index_i"},
{text:"j",url:"functions_j.html#index_j"},
{text:"k",url:"functions_k.html#index_k"},
{text:"l",url:"functions_l.html#index_l"},
{text:"m",url:"functions_m.html#index_m"},
{text:"n",url:"functions_n.html#index_n"},
{text:"o",url:"functions_o.html#index_o"},
{text:"p",url:"functions_p.html#index_p"},
{text:"q",url:"functions_q.html#index_q"},
{text:"r",url:"functions_r.html#index_r"},
{text:"s",url:"functions_s.html#index_s"},
{text:"t",url:"functions_t.html#index_t"},
{text:"u",url:"functions_u.html#index_u"},
{text:"v",url:"functions_v.html#index_v"},
{text:"w",url:"functions_w.html#index_w"},
{text:"x",url:"functions_x.html#index_x"},
{text:"y",url:"functions_y.html#index_y"},
{text:"z",url:"functions_z.html#index_z"},
{text:"~",url:"functions_~.html#index__7E"}]},
{text:"Functions",url:"functions_func.html",children:[
{text:"a",url:"functions_func.html#index_a"},
{text:"b",url:"functions_func_b.html#index_b"},
{text:"c",url:"functions_func_c.html#index_c"},
{text:"d",url:"functions_func_d.html#index_d"},
{text:"e",url:"functions_func_e.html#index_e"},
{text:"f",url:"functions_func_f.html#index_f"},
{text:"g",url:"functions_func_g.html#index_g"},
{text:"h",url:"functions_func_h.html#index_h"},
{text:"i",url:"functions_func_i.html#index_i"},
{text:"j",url:"functions_func_j.html#index_j"},
{text:"k",url:"functions_func_k.html#index_k"},
{text:"l",url:"functions_func_l.html#index_l"},
{text:"m",url:"functions_func_m.html#index_m"},
{text:"n",url:"functions_func_n.html#index_n"},
{text:"o",url:"functions_func_o.html#index_o"},
{text:"p",url:"functions_func_p.html#index_p"},
{text:"q",url:"functions_func_q.html#index_q"},
{text:"r",url:"functions_func_r.html#index_r"},
{text:"s",url:"functions_func_s.html#index_s"},
{text:"t",url:"functions_func_t.html#index_t"},
{text:"u",url:"functions_func_u.html#index_u"},
{text:"v",url:"functions_func_v.html#index_v"},
{text:"w",url:"functions_func_w.html#index_w"},
{text:"x",url:"functions_func_x.html#index_x"},
{text:"y",url:"functions_func_y.html#index_y"},
{text:"z",url:"functions_func_z.html#index_z"},
{text:"~",url:"functions_func_~.html#index__7E"}]},
{text:"Variables",url:"functions_vars.html",children:[
{text:"_",url:"functions_vars.html#index__5F"},
{text:"a",url:"functions_vars_a.html#index_a"},
{text:"b",url:"functions_vars_b.html#index_b"},
{text:"c",url:"functions_vars_c.html#index_c"},
{text:"d",url:"functions_vars_d.html#index_d"},
{text:"e",url:"functions_vars_e.html#index_e"},
{text:"f",url:"functions_vars_f.html#index_f"},
{text:"g",url:"functions_vars_g.html#index_g"},
{text:"h",url:"functions_vars_h.html#index_h"},
{text:"i",url:"functions_vars_i.html#index_i"},
{text:"j",url:"functions_vars_j.html#index_j"},
{text:"k",url:"functions_vars_k.html#index_k"},
{text:"l",url:"functions_vars_l.html#index_l"},
{text:"m",url:"functions_vars_m.html#index_m"},
{text:"n",url:"functions_vars_n.html#index_n"},
{text:"o",url:"functions_vars_o.html#index_o"},
{text:"p",url:"functions_vars_p.html#index_p"},
{text:"q",url:"functions_vars_q.html#index_q"},
{text:"r",url:"functions_vars_r.html#index_r"},
{text:"s",url:"functions_vars_s.html#index_s"},
{text:"t",url:"functions_vars_t.html#index_t"},
{text:"u",url:"functions_vars_u.html#index_u"},
{text:"v",url:"functions_vars_v.html#index_v"},
{text:"w",url:"functions_vars_w.html#index_w"},
{text:"x",url:"functions_vars_x.html#index_x"},
{text:"y",url:"functions_vars_y.html#index_y"},
{text:"z",url:"functions_vars_z.html#index_z"}]},
{text:"Typedefs",url:"functions_type.html",children:[
{text:"a",url:"functions_type.html#index_a"},
{text:"c",url:"functions_type.html#index_c"},
{text:"d",url:"functions_type.html#index_d"},
{text:"e",url:"functions_type.html#index_e"},
{text:"f",url:"functions_type.html#index_f"},
{text:"i",url:"functions_type.html#index_i"},
{text:"l",url:"functions_type.html#index_l"},
{text:"m",url:"functions_type.html#index_m"},
{text:"n",url:"functions_type.html#index_n"},
{text:"o",url:"functions_type.html#index_o"},
{text:"p",url:"functions_type.html#index_p"},
{text:"q",url:"functions_type.html#index_q"},
{text:"r",url:"functions_type.html#index_r"},
{text:"s",url:"functions_type.html#index_s"},
{text:"t",url:"functions_type.html#index_t"},
{text:"v",url:"functions_type.html#index_v"},
{text:"w",url:"functions_type.html#index_w"},
{text:"z",url:"functions_type.html#index_z"}]},
{text:"Enumerations",url:"functions_enum.html",children:[
{text:"a",url:"functions_enum.html#index_a"},
{text:"b",url:"functions_enum.html#index_b"},
{text:"c",url:"functions_enum.html#index_c"},
{text:"d",url:"functions_enum.html#index_d"},
{text:"e",url:"functions_enum.html#index_e"},
{text:"f",url:"functions_enum.html#index_f"},
{text:"g",url:"functions_enum.html#index_g"},
{text:"h",url:"functions_enum.html#index_h"},
{text:"i",url:"functions_enum.html#index_i"},
{text:"j",url:"functions_enum.html#index_j"},
{text:"k",url:"functions_enum.html#index_k"},
{text:"l",url:"functions_enum.html#index_l"},
{text:"m",url:"functions_enum.html#index_m"},
{text:"n",url:"functions_enum.html#index_n"},
{text:"o",url:"functions_enum.html#index_o"},
{text:"p",url:"functions_enum.html#index_p"},
{text:"r",url:"functions_enum.html#index_r"},
{text:"s",url:"functions_enum.html#index_s"},
{text:"t",url:"functions_enum.html#index_t"},
{text:"u",url:"functions_enum.html#index_u"},
{text:"v",url:"functions_enum.html#index_v"},
{text:"w",url:"functions_enum.html#index_w"},
{text:"z",url:"functions_enum.html#index_z"}]},
{text:"Enumerator",url:"functions_eval.html",children:[
{text:"a",url:"functions_eval.html#index_a"},
{text:"b",url:"functions_eval_b.html#index_b"},
{text:"c",url:"functions_eval_c.html#index_c"},
{text:"d",url:"functions_eval_d.html#index_d"},
{text:"e",url:"functions_eval_e.html#index_e"},
{text:"f",url:"functions_eval_f.html#index_f"},
{text:"g",url:"functions_eval_g.html#index_g"},
{text:"h",url:"functions_eval_h.html#index_h"},
{text:"i",url:"functions_eval_i.html#index_i"},
{text:"j",url:"functions_eval_j.html#index_j"},
{text:"k",url:"functions_eval_k.html#index_k"},
{text:"l",url:"functions_eval_l.html#index_l"},
{text:"m",url:"functions_eval_m.html#index_m"},
{text:"n",url:"functions_eval_n.html#index_n"},
{text:"o",url:"functions_eval_o.html#index_o"},
{text:"p",url:"functions_eval_p.html#index_p"},
{text:"q",url:"functions_eval_q.html#index_q"},
{text:"r",url:"functions_eval_r.html#index_r"},
{text:"s",url:"functions_eval_s.html#index_s"},
{text:"t",url:"functions_eval_t.html#index_t"},
{text:"u",url:"functions_eval_u.html#index_u"},
{text:"v",url:"functions_eval_v.html#index_v"},
{text:"w",url:"functions_eval_w.html#index_w"},
{text:"x",url:"functions_eval_x.html#index_x"},
{text:"y",url:"functions_eval_y.html#index_y"},
{text:"z",url:"functions_eval_z.html#index_z"}]},
{text:"Related Functions",url:"functions_rela.html"}]}]},
{text:"Files",url:"files.html",children:[
{text:"File List",url:"files.html"},
{text:"File Members",url:"globals.html",children:[
{text:"All",url:"globals.html",children:[
{text:"_",url:"globals.html#index__5F"},
{text:"a",url:"globals_a.html#index_a"},
{text:"b",url:"globals_b.html#index_b"},
{text:"c",url:"globals_c.html#index_c"},
{text:"d",url:"globals_d.html#index_d"},
{text:"e",url:"globals_e.html#index_e"},
{text:"f",url:"globals_f.html#index_f"},
{text:"g",url:"globals_g.html#index_g"},
{text:"i",url:"globals_i.html#index_i"},
{text:"j",url:"globals_j.html#index_j"},
{text:"k",url:"globals_k.html#index_k"},
{text:"l",url:"globals_l.html#index_l"},
{text:"m",url:"globals_m.html#index_m"},
{text:"n",url:"globals_n.html#index_n"},
{text:"o",url:"globals_o.html#index_o"},
{text:"p",url:"globals_p.html#index_p"},
{text:"r",url:"globals_r.html#index_r"},
{text:"s",url:"globals_s.html#index_s"},
{text:"t",url:"globals_t.html#index_t"},
{text:"u",url:"globals_u.html#index_u"},
{text:"w",url:"globals_w.html#index_w"},
{text:"z",url:"globals_z.html#index_z"}]},
{text:"Functions",url:"globals_func.html",children:[
{text:"a",url:"globals_func.html#index_a"},
{text:"b",url:"globals_func.html#index_b"},
{text:"c",url:"globals_func.html#index_c"},
{text:"d",url:"globals_func.html#index_d"},
{text:"e",url:"globals_func.html#index_e"},
{text:"f",url:"globals_func.html#index_f"},
{text:"g",url:"globals_func.html#index_g"},
{text:"i",url:"globals_func.html#index_i"},
{text:"j",url:"globals_func.html#index_j"},
{text:"m",url:"globals_func.html#index_m"},
{text:"n",url:"globals_func.html#index_n"},
{text:"o",url:"globals_func.html#index_o"},
{text:"p",url:"globals_func.html#index_p"},
{text:"r",url:"globals_func.html#index_r"},
{text:"s",url:"globals_func.html#index_s"},
{text:"t",url:"globals_func.html#index_t"},
{text:"u",url:"globals_func.html#index_u"},
{text:"w",url:"globals_func.html#index_w"},
{text:"z",url:"globals_func.html#index_z"}]},
{text:"Variables",url:"globals_vars.html"},
{text:"Typedefs",url:"globals_type.html",children:[
{text:"a",url:"globals_type.html#index_a"},
{text:"c",url:"globals_type.html#index_c"},
{text:"d",url:"globals_type.html#index_d"},
{text:"g",url:"globals_type.html#index_g"},
{text:"i",url:"globals_type.html#index_i"},
{text:"j",url:"globals_type.html#index_j"},
{text:"k",url:"globals_type.html#index_k"},
{text:"l",url:"globals_type.html#index_l"},
{text:"m",url:"globals_type.html#index_m"},
{text:"o",url:"globals_type.html#index_o"},
{text:"p",url:"globals_type.html#index_p"},
{text:"r",url:"globals_type.html#index_r"},
{text:"s",url:"globals_type.html#index_s"},
{text:"u",url:"globals_type.html#index_u"},
{text:"w",url:"globals_type.html#index_w"},
{text:"z",url:"globals_type.html#index_z"}]},
{text:"Enumerations",url:"globals_enum.html"},
{text:"Enumerator",url:"globals_eval.html"},
{text:"Macros",url:"globals_defs.html",children:[
{text:"_",url:"globals_defs.html#index__5F"},
{text:"c",url:"globals_defs_c.html#index_c"},
{text:"d",url:"globals_defs_d.html#index_d"},
{text:"e",url:"globals_defs_e.html#index_e"},
{text:"f",url:"globals_defs_f.html#index_f"},
{text:"g",url:"globals_defs_g.html#index_g"},
{text:"j",url:"globals_defs_j.html#index_j"},
{text:"k",url:"globals_defs_k.html#index_k"},
{text:"n",url:"globals_defs_n.html#index_n"},
{text:"p",url:"globals_defs_p.html#index_p"},
{text:"s",url:"globals_defs_s.html#index_s"},
{text:"t",url:"globals_defs_t.html#index_t"},
{text:"u",url:"globals_defs_u.html#index_u"}]}]}]}]}

==> juce-docs-7.0.7-1-aarch64.pkg.tar.xz: usr/share/doc/juce/html/menudata.js <==
/*
 @licstart  The following is the entire license notice for the JavaScript code in this file.

 The MIT License (MIT)

 Copyright (C) 1997-2020 by Dimitri van Heesch

 Permission is hereby granted, free of charge, to any person obtaining a copy of this software
 and associated documentation files (the "Software"), to deal in the Software without restriction,
 including without limitation the rights to use, copy, modify, merge, publish, distribute,
 sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in all copies or
 substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING
 BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

 @licend  The above is the entire license notice for the JavaScript code in this file
*/
var menudata={children:[
{text:"Main Page",url:"index.html"},
{text:"Related Pages",url:"pages.html"},
{text:"Modules",url:"modules.html"},
{text:"Classes",url:"annotated.html",children:[
{text:"Class List",url:"annotated.html"},
{text:"Class Index",url:"classes.html"},
{text:"Class Hierarchy",url:"hierarchy.html"},
{text:"Class Members",url:"functions.html",children:[
{text:"All",url:"functions.html",children:[
{text:"a",url:"functions.html#index_a"},
{text:"b",url:"functions_b.html#index_b"},
{text:"c",url:"functions_c.html#index_c"},
{text:"d",url:"functions_d.html#index_d"},
{text:"e",url:"functions_e.html#index_e"},
{text:"f",url:"functions_f.html#index_f"},
{text:"g",url:"functions_g.html#index_g"},
{text:"h",url:"functions_h.html#index_h"},
{text:"i",url:"functions_i.html#index_i"},
{text:"j",url:"functions_j.html#index_j"},
{text:"k",url:"functions_k.html#index_k"},
{text:"l",url:"functions_l.html#index_l"},
{text:"m",url:"functions_m.html#index_m"},
{text:"n",url:"functions_n.html#index_n"},
{text:"o",url:"functions_o.html#index_o"},
{text:"p",url:"functions_p.html#index_p"},
{text:"q",url:"functions_q.html#index_q"},
{text:"r",url:"functions_r.html#index_r"},
{text:"s",url:"functions_s.html#index_s"},
{text:"t",url:"functions_t.html#index_t"},
{text:"u",url:"functions_u.html#index_u"},
{text:"v",url:"functions_v.html#index_v"},
{text:"w",url:"functions_w.html#index_w"},
{text:"x",url:"functions_x.html#index_x"},
{text:"y",url:"functions_y.html#index_y"},
{text:"z",url:"functions_z.html#index_z"},
{text:"~",url:"functions_~.html#index__7E"}]},
{text:"Functions",url:"functions_func.html",children:[
{text:"a",url:"functions_func.html#index_a"},
{text:"b",url:"functions_func_b.html#index_b"},
{text:"c",url:"functions_func_c.html#index_c"},
{text:"d",url:"functions_func_d.html#index_d"},
{text:"e",url:"functions_func_e.html#index_e"},
{text:"f",url:"functions_func_f.html#index_f"},
{text:"g",url:"functions_func_g.html#index_g"},
{text:"h",url:"functions_func_h.html#index_h"},
{text:"i",url:"functions_func_i.html#index_i"},
{text:"j",url:"functions_func_j.html#index_j"},
{text:"k",url:"functions_func_k.html#index_k"},
{text:"l",url:"functions_func_l.html#index_l"},
{text:"m",url:"functions_func_m.html#index_m"},
{text:"n",url:"functions_func_n.html#index_n"},
{text:"o",url:"functions_func_o.html#index_o"},
{text:"p",url:"functions_func_p.html#index_p"},
{text:"q",url:"functions_func_q.html#index_q"},
{text:"r",url:"functions_func_r.html#index_r"},
{text:"s",url:"functions_func_s.html#index_s"},
{text:"t",url:"functions_func_t.html#index_t"},
{text:"u",url:"functions_func_u.html#index_u"},
{text:"v",url:"functions_func_v.html#index_v"},
{text:"w",url:"functions_func_w.html#index_w"},
{text:"x",url:"functions_func_x.html#index_x"},
{text:"y",url:"functions_func_y.html#index_y"},
{text:"z",url:"functions_func_z.html#index_z"},
{text:"~",url:"functions_func_~.html#index__7E"}]},
{text:"Variables",url:"functions_vars.html",children:[
{text:"a",url:"functions_vars.html#index_a"},
{text:"b",url:"functions_vars_b.html#index_b"},
{text:"c",url:"functions_vars_c.html#index_c"},
{text:"d",url:"functions_vars_d.html#index_d"},
{text:"e",url:"functions_vars_e.html#index_e"},
{text:"f",url:"functions_vars_f.html#index_f"},
{text:"g",url:"functions_vars_g.html#index_g"},
{text:"h",url:"functions_vars_h.html#index_h"},
{text:"i",url:"functions_vars_i.html#index_i"},
{text:"j",url:"functions_vars_j.html#index_j"},
{text:"k",url:"functions_vars_k.html#index_k"},
{text:"l",url:"functions_vars_l.html#index_l"},
{text:"m",url:"functions_vars_m.html#index_m"},
{text:"n",url:"functions_vars_n.html#index_n"},
{text:"o",url:"functions_vars_o.html#index_o"},
{text:"p",url:"functions_vars_p.html#index_p"},
{text:"q",url:"functions_vars_q.html#index_q"},
{text:"r",url:"functions_vars_r.html#index_r"},
{text:"s",url:"functions_vars_s.html#index_s"},
{text:"t",url:"functions_vars_t.html#index_t"},
{text:"u",url:"functions_vars_u.html#index_u"},
{text:"v",url:"functions_vars_v.html#index_v"},
{text:"w",url:"functions_vars_w.html#index_w"},
{text:"x",url:"functions_vars_x.html#index_x"},
{text:"y",url:"functions_vars_y.html#index_y"},
{text:"z",url:"functions_vars_z.html#index_z"}]},
{text:"Typedefs",url:"functions_type.html",children:[
{text:"a",url:"functions_type.html#index_a"},
{text:"c",url:"functions_type.html#index_c"},
{text:"d",url:"functions_type.html#index_d"},
{text:"e",url:"functions_type.html#index_e"},
{text:"f",url:"functions_type.html#index_f"},
{text:"h",url:"functions_type.html#index_h"},
{text:"i",url:"functions_type.html#index_i"},
{text:"k",url:"functions_type.html#index_k"},
{text:"l",url:"functions_type.html#index_l"},
{text:"m",url:"functions_type.html#index_m"},
{text:"n",url:"functions_type.html#index_n"},
{text:"o",url:"functions_type.html#index_o"},
{text:"p",url:"functions_type.html#index_p"},
{text:"q",url:"functions_type.html#index_q"},
{text:"r",url:"functions_type.html#index_r"},
{text:"s",url:"functions_type.html#index_s"},
{text:"t",url:"functions_type.html#index_t"},
{text:"v",url:"functions_type.html#index_v"},
{text:"w",url:"functions_type.html#index_w"},
{text:"z",url:"functions_type.html#index_z"}]},
{text:"Enumerations",url:"functions_enum.html",children:[
{text:"a",url:"functions_enum.html#index_a"},
{text:"b",url:"functions_enum.html#index_b"},
{text:"c",url:"functions_enum.html#index_c"},
{text:"d",url:"functions_enum.html#index_d"},
{text:"e",url:"functions_enum.html#index_e"},
{text:"f",url:"functions_enum.html#index_f"},
{text:"g",url:"functions_enum.html#index_g"},
{text:"h",url:"functions_enum.html#index_h"},
{text:"i",url:"functions_enum.html#index_i"},
{text:"j",url:"functions_enum.html#index_j"},
{text:"k",url:"functions_enum.html#index_k"},
{text:"l",url:"functions_enum.html#index_l"},
{text:"m",url:"functions_enum.html#index_m"},
{text:"n",url:"functions_enum.html#index_n"},
{text:"o",url:"functions_enum.html#index_o"},
{text:"p",url:"functions_enum.html#index_p"},
{text:"r",url:"functions_enum.html#index_r"},
{text:"s",url:"functions_enum.html#index_s"},
{text:"t",url:"functions_enum.html#index_t"},
{text:"u",url:"functions_enum.html#index_u"},
{text:"v",url:"functions_enum.html#index_v"},
{text:"w",url:"functions_enum.html#index_w"},
{text:"z",url:"functions_enum.html#index_z"}]},
{text:"Enumerator",url:"functions_eval.html",children:[
{text:"a",url:"functions_eval.html#index_a"},
{text:"b",url:"functions_eval_b.html#index_b"},
{text:"c",url:"functions_eval_c.html#index_c"},
{text:"d",url:"functions_eval_d.html#index_d"},
{text:"e",url:"functions_eval_e.html#index_e"},
{text:"f",url:"functions_eval_f.html#index_f"},
{text:"g",url:"functions_eval_g.html#index_g"},
{text:"h",url:"functions_eval_h.html#index_h"},
{text:"i",url:"functions_eval_i.html#index_i"},
{text:"j",url:"functions_eval_j.html#index_j"},
{text:"k",url:"functions_eval_k.html#index_k"},
{text:"l",url:"functions_eval_l.html#index_l"},
{text:"m",url:"functions_eval_m.html#index_m"},
{text:"n",url:"functions_eval_n.html#index_n"},
{text:"o",url:"functions_eval_o.html#index_o"},
{text:"p",url:"functions_eval_p.html#index_p"},
{text:"q",url:"functions_eval_q.html#index_q"},
{text:"r",url:"functions_eval_r.html#index_r"},
{text:"s",url:"functions_eval_s.html#index_s"},
{text:"t",url:"functions_eval_t.html#index_t"},
{text:"u",url:"functions_eval_u.html#index_u"},
{text:"v",url:"functions_eval_v.html#index_v"},
{text:"w",url:"functions_eval_w.html#index_w"},
{text:"x",url:"functions_eval_x.html#index_x"},
{text:"y",url:"functions_eval_y.html#index_y"},
{text:"z",url:"functions_eval_z.html#index_z"}]},
{text:"Related Symbols",url:"functions_rela.html"}]}]},
{text:"Files",url:"files.html",children:[
{text:"File List",url:"files.html"},
{text:"File Members",url:"globals.html",children:[
{text:"All",url:"globals.html",children:[
{text:"_",url:"globals.html#index__5F"},
{text:"a",url:"globals_a.html#index_a"},
{text:"b",url:"globals_b.html#index_b"},
{text:"c",url:"globals_c.html#index_c"},
{text:"d",url:"globals_d.html#index_d"},
{text:"e",url:"globals_e.html#index_e"},
{text:"f",url:"globals_f.html#index_f"},
{text:"g",url:"globals_g.html#index_g"},
{text:"h",url:"globals_h.html#index_h"},
{text:"i",url:"globals_i.html#index_i"},
{text:"j",url:"globals_j.html#index_j"},
{text:"k",url:"globals_k.html#index_k"},
{text:"l",url:"globals_l.html#index_l"},
{text:"m",url:"globals_m.html#index_m"},
{text:"n",url:"globals_n.html#index_n"},
{text:"o",url:"globals_o.html#index_o"},
{text:"p",url:"globals_p.html#index_p"},
{text:"r",url:"globals_r.html#index_r"},
{text:"s",url:"globals_s.html#index_s"},
{text:"t",url:"globals_t.html#index_t"},
{text:"u",url:"globals_u.html#index_u"},
{text:"v",url:"globals_v.html#index_v"},
{text:"w",url:"globals_w.html#index_w"},
{text:"x",url:"globals_x.html#index_x"},
{text:"y",url:"globals_y.html#index_y"},
{text:"z",url:"globals_z.html#index_z"}]},
{text:"Functions",url:"globals_func.html",children:[
{text:"_",url:"globals_func.html#index__5F"},
{text:"a",url:"globals_func.html#index_a"},
{text:"b",url:"globals_func.html#index_b"},
{text:"c",url:"globals_func.html#index_c"},
{text:"d",url:"globals_func.html#index_d"},
{text:"e",url:"globals_func.html#index_e"},
{text:"f",url:"globals_func.html#index_f"},
{text:"g",url:"globals_func.html#index_g"},
{text:"h",url:"globals_func.html#index_h"},
{text:"i",url:"globals_func.html#index_i"},
{text:"j",url:"globals_func.html#index_j"},
{text:"m",url:"globals_func.html#index_m"},
{text:"n",url:"globals_func.html#index_n"},
{text:"o",url:"globals_func.html#index_o"},
{text:"p",url:"globals_func.html#index_p"},
{text:"r",url:"globals_func.html#index_r"},
{text:"s",url:"globals_func.html#index_s"},
{text:"t",url:"globals_func.html#index_t"},
{text:"u",url:"globals_func.html#index_u"},
{text:"w",url:"globals_func.html#index_w"},
{text:"z",url:"globals_func.html#index_z"}]},
{text:"Variables",url:"globals_vars.html"},
{text:"Typedefs",url:"globals_type.html",children:[
{text:"a",url:"globals_type.html#index_a"},
{text:"c",url:"globals_type.html#index_c"},
{text:"d",url:"globals_type.html#index_d"},
{text:"g",url:"globals_type.html#index_g"},
{text:"i",url:"globals_type.html#index_i"},
{text:"j",url:"globals_type.html#index_j"},
{text:"k",url:"globals_type.html#index_k"},
{text:"l",url:"globals_type.html#index_l"},
{text:"m",url:"globals_type.html#index_m"},
{text:"n",url:"globals_type.html#index_n"},
{text:"o",url:"globals_type.html#index_o"},
{text:"p",url:"globals_type.html#index_p"},
{text:"r",url:"globals_type.html#index_r"},
{text:"s",url:"globals_type.html#index_s"},
{text:"u",url:"globals_type.html#index_u"},
{text:"v",url:"globals_type.html#index_v"},
{text:"w",url:"globals_type.html#index_w"},
{text:"z",url:"globals_type.html#index_z"}]},
{text:"Enumerations",url:"globals_enum.html"},
{text:"Enumerator",url:"globals_eval.html"},
{text:"Macros",url:"globals_defs.html",children:[
{text:"_",url:"globals_defs.html#index__5F"},
{text:"c",url:"globals_defs_c.html#index_c"},
{text:"d",url:"globals_defs_d.html#index_d"},
{text:"e",url:"globals_defs_e.html#index_e"},
{text:"f",url:"globals_defs_f.html#index_f"},
{text:"g",url:"globals_defs_g.html#index_g"},
{text:"j",url:"globals_defs_j.html#index_j"},
{text:"k",url:"globals_defs_k.html#index_k"},
{text:"l",url:"globals_defs_l.html#index_l"},
{text:"n",url:"globals_defs_n.html#index_n"},
{text:"p",url:"globals_defs_p.html#index_p"},
{text:"s",url:"globals_defs_s.html#index_s"},
{text:"t",url:"globals_defs_t.html#index_t"},
{text:"u",url:"globals_defs_u.html#index_u"},
{text:"x",url:"globals_defs_x.html#index_x"},
{text:"z",url:"globals_defs_z.html#index_z"}]}]}]}]}
